# KlebLib

KlebLib is a Python library consisting of a wide variety of classes and functions, all of questionable usefulness.

KlebLib currently includes:
* Fractions
* Polynomials
* Rounding
* Base Conversion
* Universal Addition

## Documentation 
Comprehensive (ish) documentation for KlebLib can be found here: https://github.com/Spartan2909/KlebLib/wiki

## Acknowledgements
 * Kai Kerlaff, for his work on baseconversion and universaladdition
